@@ -13,12 +13,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
+from typing import MutableMapping, MutableSequence
 
 from google.iam.v1 import policy_pb2  # type: ignore
+import proto  # type: ignore
 
-
-__protobuf__ = proto.module(package="google.iam.v1.logging", manifest={"AuditData",},)
+__protobuf__ = proto.module(
+    package="google.iam.v1.logging",
+    manifest={
+        "AuditData",
+    },
+)
 
 
 class AuditData(proto.Message):
@@ -32,7 +37,11 @@ class AuditData(proto.Message):
             the newly set policy.
     """
 
-    policy_delta = proto.Field(proto.MESSAGE, number=2, message=policy_pb2.PolicyDelta,)
+    policy_delta: policy_pb2.PolicyDelta = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=policy_pb2.PolicyDelta,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
